@@ -116,8 +116,8 @@ def cat_transform(X_train, X_test, cat_type, path=''):
     for i in cat_type:
         dict_ = dict( enumerate(X_train[i].cat.categories ) )
         dict_inv_ = {v: k for k, v in dict_.items()}
-        X_train[i] = X_train[i].map(dict_inv_)
-        X_test[i] = X_test[i].map(dict_inv_)
+        X_train[i] = X_train[i].map(dict_inv_).astype(int)
+        X_test[i] = X_test[i].map(dict_inv_).astype(int)
         dict_list.append(dict_)
         dict_inv_list.append(dict_inv_list)
     dict_name = f'{path}dict_list_cat'
@@ -130,17 +130,19 @@ def cat_transform(X_train, X_test, cat_type, path=''):
 
 def cont_standardize(X_train, X_test, y_train, y_test, cat_type=None, id_type=None, transform_y=True, path='', standardizer='StandardScaler'):
     "Function to standardize the continuous variables and save the standardizer. This is done on the train dataset and used for the test dataset. Standardizer can either be StandardScaler or MinMaxScaler. If id_type is defined the function will ignore these columns from standardization. If transform_y is False the function will not transform the target variable."
+    cont_type = list(X_train.columns)
     if standardizer =='StandardScaler':
         scaler = StandardScaler()
-        if cat_type==None:
-            cont_type = list(X_train.columns)
+        if cat_type==None and id_type==None:
+            cont_type = cont_type
+        elif cat_type==None:
             cont_type.remove(id_type)
         elif id_type==None:
-            list(set(X_train.columns) - set(cat_type))
+            list(set(cont_type) - set(cat_type))
         elif cat_type==None and id_type==None:
-            cont_type = list(X_train.columns)
+            cont_type = cont_type
         else:
-            cont_type = list(set(X_train.columns) - set(cat_type))
+            cont_type = list(set(cont_type) - set(cat_type))
             cont_type.remove(id_type)
 
         X_train[cont_type] = scaler.fit_transform(X_train[cont_type])
@@ -152,7 +154,7 @@ def cont_standardize(X_train, X_test, y_train, y_test, cat_type=None, id_type=No
             y_train = scaler_y.fit_transform(y_train.values.reshape(-1, 1))
             y_test = scaler_y.transform(y_test.values.reshape(-1, 1))
             scaler_y_name = f'{path}StandardScaler_y'
-            save_obj(scaler_y, scaler_name)
+            save_obj(scaler_y, scaler_y_name)
         else:
             pass
         if transform_y:
@@ -162,15 +164,14 @@ def cont_standardize(X_train, X_test, y_train, y_test, cat_type=None, id_type=No
 
     elif standardizer =='MinMaxScaler':
         scaler = MinMaxScaler()
-        if cat_type==None:
-            cont_type = list(X_train.columns)
+        if cat_type==None and id_type==None:
+            cont_type = cont_type
+        elif cat_type==None:
             cont_type.remove(id_type)
         elif id_type==None:
-            list(set(X_train.columns) - set(id_type))
-        elif cat_type==None and id_type==None:
-            cont_type = list(X_train.columns)
+            list(set(cont_type) - set(cat_type))
         else:
-            cont_type = list(set(X_train.columns) - set(cat_type))
+            cont_type = list(set(cont_type) - set(cat_type))
             cont_type.remove(id_type)
 
         X_train[cont_type] = scaler.fit_transform(X_train[cont_type])
@@ -182,7 +183,7 @@ def cont_standardize(X_train, X_test, y_train, y_test, cat_type=None, id_type=No
             y_train = scaler_y.fit_transform(y_train.values.reshape(-1, 1))
             y_test = scaler_y.transform(y_test.values.reshape(-1, 1))
             scaler_y_name = f'{path}MinMaxScaler_y'
-            save_obj(scaler_y, scaler_name)
+            save_obj(scaler_y, scaler_y_name)
         else:
             pass
         if transform_y:
@@ -191,4 +192,27 @@ def cont_standardize(X_train, X_test, y_train, y_test, cat_type=None, id_type=No
             return X_train, X_test, y_train, y_test, scaler
 
     else:
-        print('standardizer can either be StandardScaler or MinMaxScaler')   
\ No newline at end of file
+        print('standardizer can either be StandardScaler or MinMaxScaler')   
+        
+def cont_standardize_df(df, cat_type=None, id_type=None, path='', standardizer='StandardScaler'):
+    "Function to standardize the continuous variables and save the standardizer. This is done for the whole dataset. Standardizer can either be StandardScaler or MinMaxScaler. If id_type is defined the function will ignore these columns from standardization."
+    cont_type = list(df.columns)
+    if standardizer =='StandardScaler':
+        scaler = StandardScaler()
+        if cat_type==None and id_type==None:
+            cont_type = cont_type
+        elif cat_type==None:
+            cont_type.remove(id_type)
+        elif id_type==None:
+            list(set(cont_type) - set(cat_type))
+        elif cat_type==None and id_type==None:
+            cont_type = cont_type
+        else:
+            cont_type = list(set(cont_type) - set(cat_type))
+            cont_type.remove(id_type)
+            
+        df[cont_type] = scaler.fit_transform(df.loc[:,cont_type])
+        scaler_name = f'{path}StandardScaler'
+        save_obj(scaler, scaler_name)
+        
+        return df, scaler
\ No newline at end of file
